@@ -128,7 +128,6 @@ SpectacleCore::SpectacleCore(QObject *parent)
     // essential connections
     connect(SelectionEditor::instance(), &SelectionEditor::accepted,
             this, [this](const QRectF &rect, const ExportManager::Actions &actions){
-        ExportManager::instance()->updateTimestamp();
         m_returnToViewer = m_startMode == StartMode::Gui;
         if (m_videoMode) {
             const auto captureWindows = CaptureWindow::instances();
@@ -155,6 +154,7 @@ SpectacleCore::SpectacleCore(QObject *parent)
             // showViewerIfGuiMode(true);
             bool includePointer = m_cliOptions[CommandLineOptions::Pointer];
             includePointer |= m_startMode != StartMode::Background && Settings::videoIncludePointer();
+            ExportManager::instance()->updateTimestamp();
             const auto &output = m_outputUrl.isLocalFile() ? videoOutputUrl() : QUrl();
             static const auto rectKey = u"rect"_s;
             m_videoPlatform->startRecording(output, VideoPlatform::Region, {{rectKey, rect}}, includePointer);
@@ -193,6 +193,8 @@ SpectacleCore::SpectacleCore(QObject *parent)
         setVideoMode(false);
         m_annotationDocument->clearAnnotations();
         m_annotationDocument->setBaseImage(image);
+        setExportImage(image);
+        ExportManager::instance()->updateTimestamp();
         SelectionEditor::instance()->reset();
         initCaptureWindows(CaptureWindow::Image);
         SpectacleWindow::setTitleForAll(SpectacleWindow::Unsaved);
@@ -281,7 +283,33 @@ SpectacleCore::SpectacleCore(QObject *parent)
                 SpectacleCore::instance()->finishRecording();
             });
             const auto messageTitle = i18nc("recording notification title", "Spectacle is Recording");
-            const auto messageBody = i18nc("recording notification message", "Click the system tray icon to finish recording");
+            auto getSimpleDefaultShortcut = [] {
+                const auto shortcuts = KGlobalAccel::self()->shortcut(ShortcutActions::self()->recordRegionAction());
+                if (shortcuts.contains(QKeySequence{Qt::META | Qt::Key_R})) {
+                    return QKeySequence{Qt::META | Qt::Key_R};
+                }
+                return QKeySequence{};
+            };
+            auto getShortcut = [](const auto &list) {
+                auto it = std::find_if(list.cbegin(), list.cend(), [](const QKeySequence &shortcut) {
+                    return !shortcut.isEmpty();
+                });
+                return it != list.cend() ? *it : QKeySequence{};
+            };
+            QKeySequence stopShortcut = getSimpleDefaultShortcut();
+            if (stopShortcut.isEmpty()) {
+                auto mode = m_videoPlatform->recordingMode();
+                if (mode == VideoPlatform::Screen) {
+                    stopShortcut = getShortcut(KGlobalAccel::self()->shortcut(ShortcutActions::self()->recordScreenAction()));
+                } else if (mode == VideoPlatform::Window) {
+                    stopShortcut = getShortcut(KGlobalAccel::self()->shortcut(ShortcutActions::self()->recordWindowAction()));
+                } else if (mode == VideoPlatform::Region) {
+                    stopShortcut = getShortcut(KGlobalAccel::self()->shortcut(ShortcutActions::self()->recordRegionAction()));
+                }
+            }
+            const auto messageBody = stopShortcut.isEmpty()
+                ? i18nc("recording notification message without shortcut", "To finish the recording, click the pulsing red System Tray icon.")
+                : xi18nc("recording notification message with shortcut", "To finish the recording, click the pulsing red System Tray icon or press <shortcut>%1</shortcut>.", stopShortcut.toString(QKeySequence::NativeText));
             auto notification = new KNotification(u"notification"_s, KNotification::CloseOnTimeout | KNotification::DefaultEvent, this);
             notification->setTitle(messageTitle);
             notification->setText(messageBody);
@@ -662,7 +690,7 @@ void SpectacleCore::activate(const QStringList &arguments, const QString &workin
     if (!m_cliOptions[Option::Gui]
         && !m_cliOptions[Option::LaunchOnly]
         && !m_cliOptions[Option::EditExisting]) {
-        // Background gets precidence over DBus
+        // Background gets precedence over DBus
         if (m_cliOptions[Option::Background]) {
             m_startMode = StartMode::Background;
         } else if (m_cliOptions[Option::DBus]) {
